The Process Discovery tab is the entry point to the webapp, where you will be able to get a detailed understanding of the process data. It consists of a visualization screen where the process is displayed and a left-hand side menu screen where filters and selectors are available to configure the visualization.

# Visualization

![Visualization.png](5NPqqxhN3ofQ)

The graph represents an aggregation of all the traces which match the set Filters. Each node represents an activity with its name written inside, except two specific activities:

-  **START**  all nodes linked to this activity are starting activities
-  **END**  all nodes linked to this activity are ending activities

Activities are color-coded according to their frequency, or their time depending on the selected option, in the process graph displayed. A legend at the top of the graph links color with frequency. On the top-left corner additional information is available about the traces that are displayed. The first number is  the number of traces actually displayed on the screen, which consist of Filtered traces when including the Variants filter and the second number is the total number of traces in the data, before any filtering happens.

![Visualization Time.png](Rd6AkA0UgJaU)

Nodes are linked together with directed arrows. The number next to an arrow indicates the number of transitions from the source node to the target node. This information can be switched to show Performance by clicking the toggle button 'Frequency Time'  in the top-right corner. When toggled, it will show the average time spent on the transition, in a human-readable format, as shown in the screenshot above.

When the toggle is set to time, depending on whether the end timestamp is configured the color code and the time displayed in the brackets will indicate:

- if end timestamp is set: the processing time for each activity.
- if end timestamp is not set: the average time between this activity and the next one.

# Process Selector

![Process.png](mYtcfg7GKrQu)

At the top of the Filter section a Process dropdown allows you to define and adjust reference processes. The list of Processes selected here included any that have previously been Saved. To save a Process, select 'Save current process' in the dropdown, enter the name of the process in the input zone, and press the save button. Saving a process creates three objects in the folder [saved_processes](managed_folder:1rhVX912):  

- The 'Directly Follows' graph dot object that is displayed
- The Petri Net that was created using the [inductive miner](article:3) algorithm
- The Filters defined on the left-hand side

The action menu allows you to apply the Filters saved in a previously defined process with the Apply option. The Delete option deletes a saved process.

These features make is possible to save, share and compare various processes with different filters and options applied.

# Selectors

![Selectors.png](JTPt0RcYEvgS)

The selectors listed above are the defaults present for every analysis. These selectors will always select full traces, never only parts of them. Every time a selector is modified, the variants filter and the right-hand side visualization will be updated. Each of these selectors is described here:

- Starting at: The minimum timestamp of the traces (if intersecting is disabled)
- Ending at: The maximum timestamp of the traces (if intersecting is disabled)
- Strictly contained: If enabled, the traces filtered are the ones matching or within the above range. Otherwise, traces must entirely within the above range.
- Starting activities: Select the start activities to show in the visualization
- Ending activities: Select the end activities to show in the visualization
- Traces duration: the time it took to go from the start to the end of a trace. This filter enables the selection of traces according to their case performance.

Some optional selectors can be included when selecting additional columns from the workflow dataset through the [Dataiku Application](article:7). Numerical attributes will be added with a slider while categorical attributes will be added as a multi-select dropdown.

![Variants.png](nYur6WC5aHnv)

The Variant filter is a filter applied after all other filters. A Variant is a unique sequence of activities (traces) that can be observed within the process data. This filter enables the selection of the number of most frequent variants that will be shown in the visualization. The number of variants defaults at 10 and is capped at 100. Plotting too many variants will fail as the graph will get too large to display. This functionality is one of the most important for ensuring a usable and interpretable visual graph.

# Filters

![Filters.png](nUGOAEHuxgnE)

At the bottom of the left-hand side menu are filters that alter the traces by removing some activities. These filters are useful for cleaning the data of uninformative steps that might muddy a visual analysis without adding useful information. The visualization will update after each modification of the filters occurs, however overall statistics that are displayed in the pop-up windows will not be effected until the modifications are pushed to the flow using the bottom button. Three filters are available:

- Exclude activities: Select from the multi select dropdown the activities that should be removed from the data. Some activities you may wish to remove in this way include 'automatic' activities and always happen before or after another one and which therefore add complexity to the graph but little incremental information.
- Time before activity: Filter out the activities that have taken place less than the selected number of seconds after the previous activity. This filter is useful when machine processes generate multiple activities in very quick succession, and therefore including all of them would add complexity with little incremental insight.
- Looping activities: Some activities are executed multiple times in a row and for some analysis such information may not be valuable. Such activities also create many 'similar' variants.

As with Variants the effective use of the above filtering tools is an important and very impactful part of a process mining project. You may also wish to consider using Dataiku's powerful data wrangling capabilities to refine your process data prior to loading it into the Process Mining Application, to ensure you gain even more impactful and actionable insights.

# Pop-up Windows

The visualization also includes pop-up windows that appear when the user clicks on nodes or edges.

![Popup.png](ch5gb8uBeX6X)

For each node, a pop-up appears when clicking on it, displaying the following information:

- Title: the name of the selected node
- The frequency of the selected activity in the overall traces
- The most likely activity following the selected node. If the activity is most often an end activity, it will say end activity. Also gives the historical likelihood of going to this most probable following node
- The most likely activity preceding the selected node. If the activity is most often a start activity, it will say start activity. Also gives the historical likelihood of coming from this most probable preceding node

To close the window, press the 'X' on the top-right corner of the window.

![Popup Time.png](8kJXQsE36O6V)

For each edge, a pop-up appears when clicking on it. It displays the following information:

- Title: the name of the selected edge, indicating the source node and the target node
- The frequency of the transition in the overall traces
- The average, min, and max time for this transition compared to all traces (not only the displayed ones). Hence this time might mismatch with the average time indicated on the edge when the toggle time is selected because the average is not computed on the same set of traces.

To close the window, press the 'X' on the top-right corner of the window.

# Save a Visualization

To export a visualization outside the webapp, you can save it using the top-right 'Save' button.

![Save Modal.png](BadyP6yMCbr7)

Clicking on the button will open the above modal, enter a name for the visualization and press save. If the name already exists, the file will be overwritten. The saved visualizations are stored in the flow in the [saved_viz](managed_folder:LsTJHTYd) folder. From there, they can easily be published in the dashboard or downloaded.